# PltPack
## _Bind your matplotlib functions with data_

PltPack is a lightweight packaging tool for storing and exchanging data & code bound in a single file. It is mainly created to accelerate scientific work and is focused on supporting matplotlib package for exchanging scientific figures. Integrated with Jupyter Notebook.

Install from PyPi with pip:

```
pip install plt_pack
```

### LICENSE
MIT